package Crate;

our $VERSION = '0.003';

1;

__END__

=head1 NAME

Crate - Everything that PDK modules needs

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Crate'>

=head1 CONTENTS

=over 4

=item *

Term::ReadLine::Gnu

=item *

Parallel::ForkManager

=item *

local::lib

=item *

Moose

=item *

Mojolicious

=item *

Text::Diff

=item *

Expect

=item *

Try::Tiny

=item *

Data::Printer

=item *

Storable

=item *

App::cpanminus

=item *

File::Slurper

=item *

DBIx::Custom

=item *

Spreadsheet::ParseExcel

=item *

List::MoreUtils

=item *

Mail::Sender

=item *

NetAddr::IP

=item *

DateTime

=item *

Template::Toolkit

=item *

Perl::Tidy

=item *

Perl::Critic

=item *

Getopt::Long

=item *

Log::Log4perl

=item *

Text::CSV

=item *

JSON::PP

=item *

File::Slurp

=item *

Excel::Writer::XLSX

=item *

Spreadsheet::ParseExcel

=item *

Encode

=item *

Spreadsheet::Read

=item *

Dist::Zilla

=item *

Code::TidyAll

=item *

Data::Validate::IP

=item *

Net::OpenSSH

=back

=head1 DESCRIPTION

Everything that PDK modules needs. What can I say more?

=head1 AUTHOR

WENWU YAN <968828@gmail.com>

=cut

